NSSALoss
========

.. currentmodule:: pykeen.losses

.. autoclass:: NSSALoss
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~NSSALoss.hpo_default
      ~NSSALoss.synonyms

   .. rubric:: Methods Summary

   .. autosummary::

      ~NSSALoss.negative_loss_term_unreduced
      ~NSSALoss.positive_loss_term

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
   .. autoattribute:: synonyms

   .. rubric:: Methods Documentation

   .. automethod:: negative_loss_term_unreduced
   .. automethod:: positive_loss_term
